Documentation
¶
Overview ¶
Package features provides modular feature mutations for the ingress primitive example.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TLSFeature ¶
TLSFeature adds a TLS entry when enabled.
func VersionAnnotation ¶
VersionAnnotation sets a version annotation on the Ingress metadata.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.