Documentation
¶
Overview ¶
Package app provides a sample controller using the PVC primitive.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var AddToScheme = sharedapp.AddToScheme
AddToScheme registers the ExampleApp types with the given scheme.
Functions ¶
This section is empty.
Types ¶
type ExampleApp ¶
type ExampleApp = sharedapp.ExampleApp
ExampleApp re-exports the shared CRD type so callers in this package need no import alias.
type ExampleAppList ¶
type ExampleAppList = sharedapp.ExampleAppList
ExampleAppList re-exports the shared list type.
type ExampleAppSpec ¶
type ExampleAppSpec = sharedapp.ExampleAppSpec
ExampleAppSpec re-exports the shared spec type.
type ExampleAppStatus ¶
type ExampleAppStatus = sharedapp.ExampleAppStatus
ExampleAppStatus re-exports the shared status type.
type ExampleController ¶
type ExampleController struct {
client.Client
Scheme *runtime.Scheme
Recorder record.EventRecorder
Metrics component.Recorder
// NewPVCResource is a factory function to create the PVC resource.
// This allows us to inject the resource construction logic.
NewPVCResource func(*ExampleApp) (component.Resource, error)
}
ExampleController reconciles an ExampleApp object using the component framework.
func (*ExampleController) Reconcile ¶
func (r *ExampleController) Reconcile(ctx context.Context, owner *ExampleApp) error
Reconcile performs the reconciliation for a single ExampleApp.
Click to show internal directories.
Click to hide internal directories.