features

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package features provides sample mutations for the role primitive example.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BaseRuleMutation

func BaseRuleMutation(version string) role.Mutation

BaseRuleMutation sets the foundational RBAC rules for the application. It is always enabled.

func MetricsAccessMutation

func MetricsAccessMutation(version string, enableMetrics bool) role.Mutation

MetricsAccessMutation adds permission to read services for metrics scraping. It is enabled when enableMetrics is true.

func SecretAccessMutation

func SecretAccessMutation(version string, enableTracing bool) role.Mutation

SecretAccessMutation adds permission to read secrets. It is enabled when enableTracing is true (tracing requires reading TLS secrets).

func VersionLabelMutation

func VersionLabelMutation(version string) role.Mutation

VersionLabelMutation sets the app.kubernetes.io/version label on the Role. It is always enabled.

Types

This section is empty.

Jump to